@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: cf.c 305 2020-08-06 20:12:59Z leres $ (XSE)
+ * @(#) $Id: cf.c 314 2022-07-15 22:48:33Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2015, 2017, 2018, 2019, 2020
  *	Craig Leres
@@ -41,7 +41,7 @@
 /* Forwards */
 static char *dstrmerge(char *, char *);
 static void freelist(struct list *);
-static struct list *makelist(char *);
+static struct list *makelist(char *, int);
 static int readcf(const char *, struct cf *, int);
 static void fixpath(char **);
 
@@ -298,7 +298,7 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 			if (*lpp != NULL)
 				freelist(*lpp);
 			n += suck2dot(f, &cp3, 0);
-			*lpp = makelist(cp3);
+			*lpp = makelist(cp3, 1);
 			free(cp3);
 			continue;
 		}
@@ -323,7 +323,7 @@ readcf(const char *fn, struct cf *cf, int mustexist)
 				exit(1);
 			}
 			n += suck2dot(f, &cp3, 1);
-			*lpp = makelist(cp3);
+			*lpp = makelist(cp3, 0);
 			free(cp3);
 			continue;
 		}
@@ -612,7 +612,7 @@ freecf(struct cf *cf)
 }
 
 static struct list *
-makelist(char *str)
+makelist(char *str, int noval)
 {
 	int i, n;
 	char *cp, *cp2;
@@ -668,42 +668,47 @@ makelist(char *str)
 		if (cp == NULL)
 			break;
 
-		/* Terminate value */
-		*cp++ = '\0';
+		/* Trim newline and terminate value */
+		*cp = '\0';
 
-		/* Find end of key */
-		cp2 = lp->l_key;
-		while (!isspace(*cp2) && *cp2 != '\0') {
-			/* blackslash escapes next character */
-			if (*cp2 == '\\' && cp[1] != '\0')
-				memmove(cp2, cp2 + 1, strlen(cp2 + 1) + 1);
-			++cp2;
-		}
-
-		if (*cp2 == '\0') {
-			/* Save start of value */
-			lp->l_val = cp2;
-		} else {
-			/* Terminate key */
-			*cp2++ = '\0';
+		/* Find start of value */
+		cp2 = cp - 1;
+		++cp;
 
+		if (!noval) {
 			/* Find start of value */
-			while (isspace(*cp2))
-				++cp2;
+			while (cp2 > lp->l_key) {
+				--cp2;
+				if (isspace(*cp2))
+					break;
+			}
 
-			/* Save start of value */
-			lp->l_val = cp2;
+			if (isblank(*cp2)) {
+				/* Terminate key */
+				*cp2++ = '\0';
+				/* Start of value */
+				lp->l_val = cp2;
+			}
 		}
 
 		/* Save stuff */
 		lp->l_key = strdup(lp->l_key);
-		lp->l_val = strdup(lp->l_val);
-		if (lp->l_key == NULL || lp->l_val == NULL) {
+		if (lp->l_key == NULL) {
 			fprintf(stderr, "%s: makelist: strdup: %s\n",
 			    prog, strerror(errno));
 			exit(1);
 		}
 
+		if (noval) {
+			lp->l_val = NULL;
+		} else {
+			lp->l_val = strdup(lp->l_val);
+			if (lp->l_val == NULL) {
+				fprintf(stderr, "%s: makelist: strdup: %s\n",
+				    prog, strerror(errno));
+				exit(1);
+			}
+		}
 	}
 
 	return (list);
