@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: webindex.c 309 2022-06-20 20:37:35Z leres $ (XSE)
+ * @(#) $Id: webindex.c 314 2022-07-15 22:48:33Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022
  *	Craig Leres
@@ -517,11 +517,14 @@ process(const char *dname)
 	}
 
 	/* Transfer configured timestamps */
-	if (cf->c_timestamps != NULL)
-		for (wp = webfiles, i = 0; i < nwebfiles; ++i, ++wp)
+	if (cf->c_timestamps != NULL) {
+		for (wp = webfiles, i = 0; i < nwebfiles; ++i, ++wp) {
 			if ((cp = getlistval(cf->c_timestamps,
-			    wp->w_name, 0)) != NULL)
+			    wp->w_name, 0)) != NULL) {
 				wp->w_timestamp = (time_t)atol(cp);
+			}
+		}
+	}
 
 	/* Sort names; we must do this before calling hookupthumbnails() */
 	sortwebfiles(cf, webfiles, nwebfiles);
@@ -908,8 +911,8 @@ processfile(FILE *f, struct webfile *wp, struct cf *cf,
 			*cp = '\0';
 			(void)strftime(cp, sizeof(buf) - strlen(buf), p, tm);
 		} else if (wp->w_timestamp == 0 && cf->c_timestamps != NULL)
-			fprintf(stderr, "%s: warning: %s%s%s:"
-			    " missing timestamp\n",
+			fprintf(stderr,
+			    "%s: warning: %s%s%s: missing timestamp\n",
 			    prog, affix, prefix, wp->w_name);
 		cp = buf;
 		if (*cp != '\0')
